package com.gic.haoban.manage.service.service.out.impl.chat;

import java.util.List;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.BasePageInfo;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.PageHelperUtils;
import com.gic.haoban.manage.api.dto.chat.ChatEventDTO;
import com.gic.haoban.manage.api.dto.chat.GroupChatDTO;
import com.gic.haoban.manage.api.dto.qdto.chat.GroupChatSearchQDTO;
import com.gic.haoban.manage.api.service.chat.GroupChatApiService;
import com.gic.haoban.manage.service.pojo.bo.chat.GroupChatBO;
import com.gic.haoban.manage.service.service.chat.GroupChatService;

@Service("groupChatApiService")
public class GroupChatApiServiceImpl implements GroupChatApiService {

    private static final Logger logger = LogManager.getLogger(GroupChatApiService.class);

    @Autowired
    private GroupChatService groupChatService;

    @Override
    public ServiceResponse<Page<GroupChatDTO>> listPage(GroupChatSearchQDTO qdto, BasePageInfo basePageInfo) {
        Page<GroupChatBO> page = this.groupChatService.listPage(qdto, basePageInfo);
        Page<GroupChatDTO> resultPage = PageHelperUtils.changePageToCurrentPage(page, GroupChatDTO.class);
        return ServiceResponse.success(resultPage);
    }

    @Override
    public ServiceResponse<GroupChatDTO> detail(String wxEnterpriseId, Long groupChatId) {
        GroupChatBO bo = this.groupChatService.detail(wxEnterpriseId, groupChatId);
        GroupChatDTO dto = EntityUtil.changeEntityByJSON(GroupChatDTO.class, bo);
        return ServiceResponse.success(dto);
    }

    @Override
    public ServiceResponse<Void> refreshChatInfo(Long chatHmId) {
        this.groupChatService.refreshChatInfo(chatHmId);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> refreshWxEnterpriseChatInfo(String wxEnterpriseId) {
        this.groupChatService.initEnterpriseGroupChat(wxEnterpriseId);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> updateChatEnterpriseId(String wxEnterpriseId, String enterpriseId,
            List<Long> groupChatIdList) {
        this.groupChatService.updateChatEnterpriseId(wxEnterpriseId, enterpriseId, groupChatIdList);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> qwEventNotice(ChatEventDTO dto) {
        logger.info("收到群事件,params={}", JSON.toJSONString(dto));
        String changeType = dto.getChangeType();
        String wxChatId = dto.getChatId();
        String corpid = dto.getCorpid();
        // 群解散事件
        if ("dismiss".equals(changeType)) {
            this.groupChatService.dismissChat(corpid, wxChatId);
        } else if ("create".equals(changeType)) {
            // 创建群
            this.groupChatService.createChat(corpid, wxChatId);
        } else {
            String updateDetail = dto.getUpdateDetail();
            this.groupChatService.updateChat(corpid, wxChatId, updateDetail, JSON.toJSONString(dto));
        }
        return ServiceResponse.success();
    }

}
